aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java56
1 files changed, 28 insertions, 28 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java
index 3158144..1289db5 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/ManifestType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,33 +10,33 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
/**
- * <p>Java class for ManifestType complex type.
+ * <p>Java-Klasse für ManifestType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="ManifestType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}Reference" maxOccurs="unbounded"/>
- * &lt;/sequence>
- * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" />
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="ManifestType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}Reference" maxOccurs="unbounded"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -61,7 +61,7 @@ public class ManifestType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the reference property.
*
* <p>
@@ -85,7 +85,7 @@ public class ManifestType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -97,7 +97,7 @@ public class ManifestType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -61,7 +61,7 @@ public class ManifestType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the reference property.
*